==> libosl_0.3.0.orig.tar.gz: libosl_0.3.0.orig/test/move_generator/attackToPinned.t.cc <==
#include "osl/move_generator/allMoves.h"
#include "osl/move_action/store.h"
#include "osl/move_generator/attackToPinned.h"
#include "osl/record/record.h"
#include "osl/record/csaRecord.h"
#include "osl/record/csaString.h"
#include "osl/container/moveVector.h"
#include "osl/apply_move/applyMove.h"

#include <cppunit/TestCase.h>
#include <cppunit/extensions/HelperMacros.h>
#include <iostream>
#include <fstream>

class AttackToPinnedTest : public CppUnit::TestFixture 
{
  CPPUNIT_TEST_SUITE(AttackToPinnedTest);
  CPPUNIT_TEST(testSimple);
  CPPUNIT_TEST_SUITE_END();
public:
  void testSimple();
};

CPPUNIT_TEST_SUITE_REGISTRATION(AttackToPinnedTest);
using namespace osl;
using namespace osl::state;
using namespace osl::move_generator;
using namespace osl::move_action;

void AttackToPinnedTest::testSimple()
{
  {
    SimpleState state=
      CsaString(
		"P1+NY+RY *  * -KI * -OU-KE *\n"
		"P2 *  *  *  *  * -GI-KI-FU *\n"
		"P3 * +TO *  *  *  *  *  * +KA\n"
		"P4 *  * +FU+UM *  *  *  *  *\n"
		"P5 *  * -KE-FU-FU *  *  * -FU\n"
		"P6+KE *  * +FU+GI-FU *  * +FU\n"
		"P7 *  *  *  *  *  *  *  *  *\n"
		"P8 *  *  *  *  *  *  *  *  * \n"
		"P9 * +OU * -GI *  * +KY * -NG\n"
		"P+00HI00KI00KE00KY00FU00FU00FU00FU00FU00FU00FU\n"
		"P-00KI00KY00FU00FU\n"
		"P-00AL\n"
		"+\n"
		).getInitialState();
    NumEffectState eState(state);
    MoveVector moves;
    {
      move_action::Store store(moves);
      GenerateAttackToPinned::generate(BLACK,eState,store);
    }
    // 歩を攻める手も生成する
    CPPUNIT_ASSERT(moves.isMember(Move(Position(1,4),KNIGHT,BLACK)));
    CPPUNIT_ASSERT(moves.isMember(Move(Position(2,3),PAWN,BLACK)));
    CPPUNIT_ASSERT(moves.isMember(Move(Position(1,2),GOLD,BLACK)));
    // 金を攻める
    CPPUNIT_ASSERT(moves.isMember(Move(Position(2,4),KNIGHT,BLACK)));
    CPPUNIT_ASSERT(moves.isMember(Move(Position(2,3),GOLD,BLACK)));
    // 利きをふさいでいる
    CPPUNIT_ASSERT(moves.isMember(Move(Position(3,3),PAWN,BLACK)));
    CPPUNIT_ASSERT(moves.isMember(Move(Position(4,3),GOLD,BLACK)));
    // 銀を攻める
    CPPUNIT_ASSERT(moves.isMember(Move(Position(4,3),PAWN,BLACK)));
    // 金を攻める
    CPPUNIT_ASSERT(moves.isMember(Move(Position(5,2),PAWN,BLACK)));
    CPPUNIT_ASSERT(moves.isMember(Move(Position(6,4),Position(7,3),PBISHOP,PTYPE_EMPTY,false,BLACK)));
  }
}

==> libosl_0.6.0.orig.tar.gz: libosl_0.6.0.orig/test/move_generator/attackToPinned.t.cc <==
#include "osl/move_generator/allMoves.h"
#include "osl/move_action/store.h"
#include "osl/move_generator/attackToPinned.h"
#include "osl/record/record.h"
#include "osl/record/csaRecord.h"
#include "osl/record/csaString.h"
#include "osl/container/moveVector.h"

#include <cppunit/TestCase.h>
#include <cppunit/extensions/HelperMacros.h>
#include <iostream>
#include <fstream>

class AttackToPinnedTest : public CppUnit::TestFixture 
{
  CPPUNIT_TEST_SUITE(AttackToPinnedTest);
  CPPUNIT_TEST(testSimple);
  CPPUNIT_TEST_SUITE_END();
public:
  void testSimple();
};

CPPUNIT_TEST_SUITE_REGISTRATION(AttackToPinnedTest);
using namespace osl;
using namespace osl::state;
using namespace osl::move_generator;
using namespace osl::move_action;

void AttackToPinnedTest::testSimple()
{
  {
    SimpleState state=
      CsaString(
		"P1+NY+RY *  * -KI * -OU-KE *\n"
		"P2 *  *  *  *  * -GI-KI-FU *\n"
		"P3 * +TO *  *  *  *  *  * +KA\n"
		"P4 *  * +FU+UM *  *  *  *  *\n"
		"P5 *  * -KE-FU-FU *  *  * -FU\n"
		"P6+KE *  * +FU+GI-FU *  * +FU\n"
		"P7 *  *  *  *  *  *  *  *  *\n"
		"P8 *  *  *  *  *  *  *  *  * \n"
		"P9 * +OU * -GI *  * +KY * -NG\n"
		"P+00HI00KI00KE00KY00FU00FU00FU00FU00FU00FU00FU\n"
		"P-00KI00KY00FU00FU\n"
		"P-00AL\n"
		"+\n"
		).getInitialState();
    NumEffectState eState(state);
    MoveVector moves;
    {
      move_action::Store store(moves);
      GenerateAttackToPinned::generate(BLACK,eState,store);
    }
    // 歩を攻める手も生成する
    CPPUNIT_ASSERT(moves.isMember(Move(Square(1,4),KNIGHT,BLACK)));
    CPPUNIT_ASSERT(moves.isMember(Move(Square(2,3),PAWN,BLACK)));
    CPPUNIT_ASSERT(moves.isMember(Move(Square(1,2),GOLD,BLACK)));
    // 金を攻める
    CPPUNIT_ASSERT(moves.isMember(Move(Square(2,4),KNIGHT,BLACK)));
    CPPUNIT_ASSERT(moves.isMember(Move(Square(2,3),GOLD,BLACK)));
    // 利きをふさいでいる
    CPPUNIT_ASSERT(moves.isMember(Move(Square(3,3),PAWN,BLACK)));
    CPPUNIT_ASSERT(moves.isMember(Move(Square(4,3),GOLD,BLACK)));
    // 銀を攻める
    CPPUNIT_ASSERT(moves.isMember(Move(Square(4,3),PAWN,BLACK)));
    // 金を攻める
    CPPUNIT_ASSERT(moves.isMember(Move(Square(5,2),PAWN,BLACK)));
    CPPUNIT_ASSERT(moves.isMember(Move(Square(6,4),Square(7,3),PBISHOP,PTYPE_EMPTY,false,BLACK)));
  }
}
